@@ -3,9 +3,9 @@ import os
 from pypgstac.db import PgstacDB
 from pypgstac.load import Methods
 
+from .loader import Loader
 from .schemas import StacCollection
 from .utils import get_db_credentials
-from .vedaloader import VEDALoader
 
 
 def ingest(collection: StacCollection):
@@ -17,7 +17,7 @@ def ingest(collection: StacCollection):
     try:
         creds = get_db_credentials(os.environ["DB_SECRET_ARN"])
         with PgstacDB(dsn=creds.dsn_string, debug=True) as db:
-            loader = VEDALoader(db=db)
+            loader = Loader(db=db)
             loader.load_collection(file=collection, insert_mode=Methods.upsert)
     except Exception as e:
         print(f"Encountered failure loading collection into pgSTAC: {e}")
@@ -29,5 +29,5 @@ def delete(collection_id: str):
     """
     creds = get_db_credentials(os.environ["DB_SECRET_ARN"])
     with PgstacDB(dsn=creds.dsn_string, debug=True) as db:
-        loader = VEDALoader(db=db)
+        loader = Loader(db=db)
         loader.delete_collection(collection_id)
